// Function to generate CAPTCHA
function generateCaptcha() {
    return fetch('https://captcha.i-as.dev/api/captcha/generate')
        .then(function(response) {
            if (!response.ok) {
                throw new Error('Failed to generate CAPTCHA');
            }
            return response.json();
        })
        .then(function(data) {
            return data;
        })
        .catch(function(error) {
            console.error('Error generating CAPTCHA:', error);
            throw error;
        });
}

// Function to verify CAPTCHA
function verifyCaptcha(id, answer) {
    var url = 'https://captcha.i-as.dev/api/captcha/verify';
    var body = {
        id: id,
        answer: answer
    };

    return fetch(url, {
        method: 'POST',
        headers: {
            'Content-Type': 'application/json'
        },
        body: JSON.stringify(body)
    })
    .then(function(response) {
        if (!response.ok) {
            throw new Error('Failed to verify CAPTCHA');
        }
        return response.json();
    })
    .then(function(data) {
        return data;
    })
    .catch(function(error) {
        console.error('Error verifying CAPTCHA:', error);
        throw error;
    });
}

// Function to refresh CAPTCHA
function refreshCaptcha() {
    var captchaContainer = document.getElementById('captcha-container');
    captchaContainer.innerHTML = ''; // Clear previous CAPTCHA
    
    generateCaptcha()
        .then(function(data) {
            var captchaId = data.id;
            var svgData = data.data;

            var svgContainer = document.createElementNS("http://www.w3.org/2000/svg", "svg");
            svgContainer.setAttribute("xmlns", "http://www.w3.org/2000/svg");
            svgContainer.setAttribute("width", "150");
            svgContainer.setAttribute("height", "50");

            var svgImage = document.createElementNS("http://www.w3.org/2000/svg", "image");
            svgImage.setAttribute("href", 'data:image/svg+xml;base64,' + btoa(svgData));
            svgImage.setAttribute("width", "100%");
            svgImage.setAttribute("height", "100%");
            svgContainer.appendChild(svgImage);

            var captchaIdInput = document.createElement('input');
            captchaIdInput.type = 'hidden';
            captchaIdInput.id = 'captcha-id';
            captchaIdInput.value = captchaId;

            captchaContainer.appendChild(svgContainer);
            captchaContainer.appendChild(captchaIdInput);
        })
        .catch(function(error) {
            console.error('Error refreshing CAPTCHA:', error);
            alert('An error occurred while generating CAPTCHA. Please try again.');
        });
}

// Function to retrieve todos from local storage
function getTodos() {
    var todos = [];
    var todosString = localStorage.getItem('todos');
    if (todosString) {
        todos = JSON.parse(todosString);
    }
    return todos;
}

// Function to save todos to local storage
function saveTodos(todos) {
    localStorage.setItem('todos', JSON.stringify(todos));
}

// Function to render todos
function renderTodos() {
    var todoList = document.getElementById('todo-list');
    var todos = getTodos();
    
    todoList.innerHTML = '';

    todos.forEach(function(todo, index) {
        var li = document.createElement('li');
        
        // Create SVG X icon
        var svgX = document.createElementNS("http://www.w3.org/2000/svg", "svg");
        svgX.setAttribute("xmlns", "http://www.w3.org/2000/svg");
        svgX.setAttribute("viewBox", "0 0 24 24");
        svgX.setAttribute("width", "18");
        svgX.setAttribute("height", "18");
        svgX.classList.add('delete-icon');
        svgX.innerHTML = `
            <path fill="none" d="M0 0h24v24H0z"/>
            <path d="M19 6.41L17.59 5 12 10.59 6.41 5 5 6.41 10.59 12 5 17.59 6.41 19 12 13.41 17.59 19 19 17.59 13.41 12 19 6.41z"/>
        `;
        
        var span = document.createElement('span');
        span.textContent = todo;
        
        li.appendChild(svgX);
        li.appendChild(span);

        svgX.addEventListener('click', function() {
            var todos = getTodos();
            todos.splice(index, 1);
            saveTodos(todos);
            renderTodos();
        });

        todoList.appendChild(li);
    });
}

function addTodo() {
    var todoInput = document.getElementById('todo-input');
    var todoText = todoInput.value.trim();
    
    var captchaAnswer = document.getElementById('captcha-answer').value.trim();
    var captchaId = document.getElementById('captcha-id').value.trim();

    if (todoText !== '' && captchaAnswer !== '' && captchaId !== '') {
        verifyCaptcha(captchaId, captchaAnswer)
            .then(function(response) {
                if (response.success) {
                    var todos = getTodos();
                    todos.push(todoText);
                    saveTodos(todos);
                    renderTodos();
                    todoInput.value = '';
                    document.getElementById('captcha-answer').value = '';
                    document.getElementById('captcha-id').value = '';
                    refreshCaptcha();
                } else {
                    alert('CAPTCHA verification failed. Please try again.');
                    refreshCaptcha();
                }
            })
            .catch(function(error) {
                console.error('Error verifying CAPTCHA:', error);
                alert('An error occurred while verifying CAPTCHA. Please try again.');
                refreshCaptcha();
            });
    } else {
        alert('Please fill out all fields.');
        refreshCaptcha();
    }
}

document.getElementById('todo-form').addEventListener('submit', function(event) {
    event.preventDefault();
    addTodo();
});
  
refreshCaptcha();
